
import java.awt.*;
import java.io.*;
import sun.audio.*;

public class AudioPlayUI extends Frame
{
	static Thread providerThread;
	static AudioProvider provider;
	static AudioIOStream stream;
	static String fileName;
	static ADPCMdecoder decoder;
	static AudioCheck check;
	static int state = NEW;

	void audioFinished()
	{
		stream = new AudioIOStream();
		decoder = new ADPCMdecoder( 800 );
		provider.close();
		if( provider instanceof FileAudioProvider )
		{
			provider = new FileAudioProvider( decoder, stream, fileName );
		}
		if( provider instanceof URLAudioProvider )
		{
			provider = new URLAudioProvider( decoder, stream, fileName );
		}

		providerThread = new Thread( provider, "AudioProvider" );
		providerThread.start();
		buttonPlay.enable();
		buttonStop.disable();
		buttonRewind.disable();
		state = READY;
		check = new AudioCheck( this, stream );
		check.start();
		System.out.println( "Player: READY" );
	}

	synchronized void buttonRewindClicked( Event event )
	{
		if( state == STOPPED )
		{
			AudioPlayer.player.stop( stream );
			AudioPlayer.player.resume();
			stream = new AudioIOStream();
			decoder = new ADPCMdecoder( 800 );
			provider.close();
			if( provider instanceof FileAudioProvider )
			{
				provider = new FileAudioProvider( decoder, stream, fileName );
			}
			if( provider instanceof URLAudioProvider )
			{
				provider = new URLAudioProvider( decoder, stream, fileName );
			}

			providerThread = new Thread( provider, "AudioProvider" );
			providerThread.start();

			buttonPlay.enable();
			buttonStop.disable();
			buttonRewind.disable();
			state = READY;
			System.out.println( "Player: READY" );
		}
	}

	synchronized void buttonStopClicked( Event event )
	{
		if( state == PLAYING )
		{
			AudioPlayer.player.suspend();
			buttonPlay.enable();
			buttonStop.disable();
			buttonRewind.enable();
			state = STOPPED;
			System.out.println( "Player: STOPPED" );
		}
	}

	synchronized void buttonPlayClicked( Event event )
	{
		if( state == READY )
		{
			AudioPlayer.player.start( (InputStream)stream );
			buttonPlay.disable();
			buttonStop.enable();
			buttonRewind.disable();
			state = PLAYING;
			System.out.println( "Player: PLAYING" );
		}
		if( state == STOPPED )
		{
			AudioPlayer.player.resume();
			buttonPlay.disable();
			buttonStop.enable();
			buttonRewind.disable();
			state = PLAYING;
			System.out.println( "Player: PLAYING" );
		}
	}

	public AudioPlayUI()
	{
		//{{INIT_CONTROLS
		setLayout(new GridLayout(1,1,0,0));
		addNotify();
		resize(insets().left + insets().right + 210,insets().top + insets().bottom + 30);
		buttonPlay = new java.awt.Button("Play");
		buttonPlay.reshape(insets().left + 0,insets().top + 0,70,30);
		add(buttonPlay);
		buttonStop = new java.awt.Button("Stop");
		buttonStop.reshape(insets().left + 73,insets().top + 0,70,30);
		add(buttonStop);
		buttonStop.disable();
		buttonRewind = new java.awt.Button("Rewind");
		buttonRewind.reshape(insets().left + 146,insets().top + 0,70,30);
		add(buttonRewind);
		buttonRewind.disable();
		setTitle("Audio Player");
		//}}

		check = new AudioCheck( this, stream );
		check.start();
	}

	public AudioPlayUI( String title )
	{
	    this();
	    setTitle( title );
	}

    public synchronized void show() {
    	move(50, 50);
    	super.show();
    }

	public boolean handleEvent( Event event )
	{
    	if( event.id == Event.WINDOW_DESTROY )
		{
            hide();         // hide the Frame
            dispose();      // free the system resources
            System.exit(0); // close the application
            return true;
    	}
		return super.handleEvent( event );
	}

	public boolean action( Event  event, Object  what )
	{
		if( event.target == buttonPlay )
		{
			buttonPlayClicked( event );
			return true;
		}
		if( event.target == buttonStop )
		{
			buttonStopClicked( event );
			return true;
		}
		if( event.target == buttonRewind )
		{
			buttonRewindClicked( event );
			return true;
		}
		return false;
	}

	static public void main( String args[] )
	{
		try
		{
			fileName = args[ 0 ];
		}
		catch( IndexOutOfBoundsException e )
		{
			System.err.println( "Usage: AudioPlay filename|url" );
			System.exit( -1 );
		}

		stream = new AudioIOStream();
		decoder = new ADPCMdecoder( 800 );

		File checkFile = new File( fileName );
		if( checkFile.exists() )
		{
			provider = new FileAudioProvider( decoder, stream, fileName );
		}
		else
		{
			provider = new URLAudioProvider( decoder, stream, fileName );
		}

		checkFile = null;
		providerThread = new Thread( provider, "AudioProvider" );
		providerThread.start();

		state = READY;
		System.out.println( "Player: READY" );

	    ( new AudioPlayUI( "Audio Player - " + fileName ) ).show();
	}

	//{{DECLARE_CONTROLS
	java.awt.Button buttonPlay;
	java.awt.Button buttonStop;
	java.awt.Button buttonRewind;
	//}}

	static final int NEW = 0;
	static final int READY = 1;
	static final int PLAYING = 2;
	static final int STOPPED = 3;
}
